Enum cache_buster::processor::NoHashCategory
source · pub enum NoHashCategory<'a> {
FileExtentions(Vec<&'a str>),
FilePaths(Vec<&'a str>),
}Expand description
Items to avoid hash calculation.
This is useful when serving vendor static files which are interlinked, where chaing
file names should mean changing how the vendor files pulls its dependencies — which are
beyond the abilities of cache_buster.
use cache_buster::NoHashCategory;
let extensions = NoHashCategory::FileExtentions(vec!["wasm"]);
let files = NoHashCategory::FileExtentions(vec!["swagger-ui-bundle.js", "favicon-16x16.png"]);Variants
FileExtentions(Vec<&'a str>)
vector of file extensions that should be avoided for hash processing
FilePaths(Vec<&'a str>)
list of file paths that should be avoided for file processing